/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the IBM RS/6000 keyboard.
 * By Tom McConnell <tmcconne@sedona.intel.com>
 */

static const KeyCode rs6k_codes [] = {

  /* Row 0 */
  118,
  120, 121, 122, 123,
  124, 125, 126, 127,
  128, 129, 130, 131,
  132, 133, 134,

  /* Row 2 */
  9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 23,
  83, 88, 93,
  98, 103, 108, 113,

  /* Row 3 */
  24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37,
  84, 89, 94,
 99, 104, 109, 114,
  
  /* Row 4 */
  38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 51,
  100, 105, 110,

  /* Row 5 */
  52, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 65,
  91,
  101, 106, 111, 116,

  /* Row 6 */
  66,
  68, 69, 70,
  72,
  87, 92, 97,
  107, 112
};
